<?php
/** Gan (贛語)
 *
 * To improve a translation please visit https://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

$fallback = 'gan-hant, zh-hant, zh-hans';

$namespaceNames = [
	NS_MEDIA            => '媒體',
	NS_SPECIAL          => '特別',
	NS_TALK             => '談詑',
	NS_USER             => '用戶',
	NS_USER_TALK        => '用戶・談詑',
	NS_PROJECT_TALK     => '$1・談詑',
	NS_FILE             => '文檔',
	NS_FILE_TALK        => '文檔・談詑',
	NS_MEDIAWIKI_TALK   => 'MediaWiki・談詑',
	NS_TEMPLATE         => '模板',
	NS_TEMPLATE_TALK    => '模板・談詑',
	NS_HELP             => '幫助',
	NS_HELP_TALK        => '幫助・談詑',
	NS_CATEGORY         => '分類',
	NS_CATEGORY_TALK    => '分類・談詑',
];

$namespaceAliases = [
	'$1_談詑' => NS_PROJECT_TALK,
];

